@@ -13,7 +13,7 @@ NTIMES = 10
 NFREQ = 5
 NPTSRC = 20
 
-ants = {0: (0, 0, 0), 1: (1, 1, 0)}
+ants = {0: (0.0, 0.0, 0.0), 1: (20.0, 20.0, 0.0)}
 
 
 def test_vis_cpu():
@@ -102,8 +102,39 @@ def test_vis_cpu():
         )
     assert np.all(~np.isnan(_vis))  # check that there are no NaN values
 
+    # Check that errors are raised when beams are input incorrectly
+    with pytest.raises(RuntimeError):
+        vis_cpu(
+            antpos,
+            freq[0],
+            eq2tops,
+            crd_eq,
+            I_sky[:, i],
+            bm_cube=None,
+            beam_list=None,
+            precision=1,
+            polarized=False,
+        )
 
-def test_simulate_vis():
+    with pytest.raises(RuntimeError):
+        vis_cpu(
+            antpos,
+            freq[0],
+            eq2tops,
+            crd_eq,
+            I_sky[:, i],
+            bm_cube=beam_cube[:, i, :, :],
+            beam_list=[beam, beam],
+            precision=1,
+            polarized=False,
+        )
+
+
+@pytest.mark.parametrize(
+    "pixel_beams,polarized",
+    [(True, False), (False, False), (False, True), (True, True)],
+)
+def test_simulate_vis(pixel_beams, polarized):
     """Test basic operation of simple wrapper around vis_cpu, `simulate_vis`."""
     # Point source equatorial coords (radians)
     ra = np.linspace(0.0, 2.0 * np.pi, NPTSRC)
@@ -131,25 +162,9 @@ def test_simulate_vis():
         freq,
         lsts,
         beams=[beam, beam],
-        pixel_beams=True,
+        pixel_beams=pixel_beams,
         beam_npix=63,
-        polarized=False,
-        precision=1,
-        latitude=-30.7215 * np.pi / 180.0,
-    )
-    assert np.all(~np.isnan(vis))  # check that there are no NaN values
-
-    # Run vis_cpu with UVBeam beams
-    vis = simulate_vis(
-        ants,
-        I_sky,
-        ra,
-        dec,
-        freq,
-        lsts,
-        beams=[beam, beam],
-        pixel_beams=False,
-        polarized=False,
+        polarized=polarized,
         precision=1,
         latitude=-30.7215 * np.pi / 180.0,
     )
